==> 1.12-CF.zip: spackenmobs/README.md <==
# Spackenmobs

## Advanced Mobs

### Friedrich Liechtenstein

![Friedrich Liechtenstein](https://i.imgur.com/GR1KQhp.png)
*"Diese Brause ist enorm."*

Friedrich Liechtenstein is your local trader for Ahoj-Brause. Provide paper and he will give you soda powder or milk him with a glass bottle to get his finest soda. He would also like to meet your mother.

### Jens

![Jens](https://i.imgur.com/J8r6q1B.png)
*"Ich hab' extrem lange Finger!"*

Jens is a small Austrian streamer with a thriving meme culture. He will get horny if you feed him Corsair RAM. He also loves surströmming, so make sure to feed him fish and reap the rewards after some time of digesting!

## Simple Mobs

### ApoRed

![ApoRed](https://i.imgur.com/w3ReO5a.png)
*"Nicht auf meine Yeezys, Digga!"*

ApoRed acts like a skeleton and insults you if you hit him.

### Baka Mitai Creeper

![Baka Mitai Creeper](https://i.imgur.com/jcI7mzM.png)
*"Dame da ne, dame yo dame na no yo..."*

Baka Mitai Creeper is disguised as a regular creeper but has a much larger explosion radius. But don't worry, it has a pretty long fuse time and plays Baka Mitai when exploding.

### Drachenlord

![Drachenlord](https://i.imgur.com/AzYF7TD.png)
*"Verdammt'n Arschlöcha!"*

Drachenlord acts like a zombie pigman and spawns in the Nether. He will get very angry if you hit him!

### Holzstammhuhn

![Holzstammhuhn](https://i.imgur.com/VEE7eMZ.png)
*"PLOCK!"*

Holzstammhuhn is a replica of Chicken's Log Chicken but it makes wooden sounds, so that's a bonus. It only exists because the German translation became a meme.

### Islamist

![Islamist](https://i.imgur.com/q8tAyN2.png)
*"Allahu Akbar!"*

Islamist acts like a creeper and will spread his faith when exploding.

### Marcell D'Avis

![Marcell D'Avis](https://i.imgur.com/MUDp0Hf.png)
*"Hallo!"*

Marcell D'Avis acts like a zombie and is the manager for customer satisfaction at 1&1. He will tell you about the benefits of 1&1's products and customer support.

### Mr. Bean

![Mr. Bean](https://i.imgur.com/YXOxre8.png)
*"Magic!"*

Mr. Bean acts like a zombie and limits his statements to "Magic" and snorting noises.

### MZTEWolf

![MZTEWolf](https://i.imgur.com/0P6Gmmy.png)
*Rust noises*

MZTEWolf acts like a wolf and is based on a lousy coder from Thuringia. It has a passion for Kotlin and Rust.

### Schalker

![Schalker](https://i.imgur.com/eUrvPnm.png)
*"Schalke 04, Liebe im Revier..."*

Schalker acts like a shulker and will spread its love for soccer and the Ruhr area.

### Smava Creeper

![Smava Creeper](https://i.imgur.com/ALnOxRo.png)
*"Wenn Kredit, dann..."*

Smava Creeper acts like a creeper and is a pesky credit agent known from the infamous TV ads. Watch out, it is twice as fast and its explosions are twice as strong! It also explodes a little faster.

## Items

To be added...

==> 1.16-CF.zip: spackenmobs/README.md <==
# Spackenmobs

**DISCLAIMER** - This mod was created just for fun and is obviously not intended to offend or hurt anyone. It's a block game after all.

## Advanced Mobs

### Friedrich Liechtenstein

![Friedrich Liechtenstein](https://i.imgur.com/GR1KQhp.png)
*"Diese Brause ist enorm."*

Friedrich Liechtenstein is your local trader for Ahoj-Brause. Provide paper and he will give you soda powder or milk him with a glass bottle to get his finest soda. He would also like to meet your mother.

### Jens

![Jens](https://i.imgur.com/J8r6q1B.png)
*"Ich hab' extrem lange Finger!"*

Jens is a small Austrian streamer with a thriving meme culture. He will get horny if you feed him Corsair RAM. He also loves surströmming, so make sure to feed him fish and reap the rewards after some time of digesting!

## Simple Mobs

### ApoRed

![ApoRed](https://i.imgur.com/w3ReO5a.png)
*"Nicht auf meine Yeezys, Digga!"*

ApoRed acts like a skeleton and insults you if you hit him.

### Baka Mitai Creeper

![Baka Mitai Creeper](https://i.imgur.com/jcI7mzM.png)
*"Dame da ne, dame yo dame na no yo..."*

Baka Mitai Creeper is disguised as a regular creeper but has a much larger explosion radius. But don't worry, it has a pretty long fuse time and plays Baka Mitai when exploding.

### Drachenlord

![Drachenlord](https://i.imgur.com/AzYF7TD.png)
*"Verdammt'n Arschlöcha!"*

1.12: Drachenlord acts like a zombie pigman and spawns in the Nether. He will get very angry if you hit him!

1.16: Drachenlord acts like a zombie and will get very angry if you hit him!

### Gisela (1.16 only)

![Gisela](https://i.imgur.com/PCaBpEs.png)
*"POMMES!"*

Gisela is the alter ego of the German YouTuber "Gewitter im Kopf". He always makes meaningful statements and runs around like crazy.

### Holzstammhuhn

![Holzstammhuhn](https://i.imgur.com/VEE7eMZ.png)
*"PLOCK!"*

Holzstammhuhn is a replica of Chicken's Log Chicken but it makes wooden sounds, so that's a bonus. It only exists because the German translation became a meme.

### Islamist

![Islamist](https://i.imgur.com/q8tAyN2.png)
*"Allahu Akbar!"*

Islamist acts like a creeper and will spread his faith when exploding.

### Marcell D'Avis

![Marcell D'Avis](https://i.imgur.com/MUDp0Hf.png)
*"Hallo!"*

Marcell D'Avis acts like a zombie and is the manager for customer satisfaction at 1&1. He will tell you about the benefits of 1&1's products and customer support.

### Mr. Bean

![Mr. Bean](https://i.imgur.com/YXOxre8.png)
*"Magic!"*

Mr. Bean acts like a zombie and limits his statements to "Magic" and snorting noises.

### MZTEWolf

![MZTEWolf](https://i.imgur.com/0P6Gmmy.png)
*Rust noises*

MZTEWolf acts like a wolf and is based on a lousy coder from Thuringia. It has a passion for Kotlin and Rust.

### Schalker

![Schalker](https://i.imgur.com/eUrvPnm.png)
*"Schalke 04, Liebe im Revier..."*

Schalker acts like a shulker and will spread its love for soccer and the Ruhr area.

### Smava Creeper

![Smava Creeper](https://i.imgur.com/ALnOxRo.png)
*"Wenn Kredit, dann..."*

Smava Creeper acts like a creeper and is a pesky credit agent known from the infamous TV ads. Watch out, it is twice as fast and its explosions are twice as strong! It also explodes a little faster.

## Items

To be added...
